@@ -481,7 +481,7 @@ gst_plugin_register_func (GstPlugin * plugin, const GstPluginDesc * desc,
   if (!gst_plugin_check_version (desc->major_version, desc->minor_version)) {
     if (GST_CAT_DEFAULT)
       GST_WARNING ("plugin \"%s\" has incompatible version, not loading",
-          plugin->filename);
+          GST_STR_NULL (plugin->filename));
     return NULL;
   }
 
@@ -489,14 +489,14 @@ gst_plugin_register_func (GstPlugin * plugin, const GstPluginDesc * desc,
       !desc->package || !desc->origin) {
     if (GST_CAT_DEFAULT)
       GST_WARNING ("plugin \"%s\" has incorrect GstPluginDesc, not loading",
-          plugin->filename);
+          GST_STR_NULL (plugin->filename));
     return NULL;
   }
 
   if (!gst_plugin_check_license (desc->license)) {
     if (GST_CAT_DEFAULT)
       GST_WARNING ("plugin \"%s\" has invalid license \"%s\", not loading",
-          plugin->filename, desc->license);
+          GST_STR_NULL (plugin->filename), desc->license);
     return NULL;
   }
 
@@ -514,13 +514,15 @@ gst_plugin_register_func (GstPlugin * plugin, const GstPluginDesc * desc,
   if (user_data) {
     if (!(((GstPluginInitFullFunc) (desc->plugin_init)) (plugin, user_data))) {
       if (GST_CAT_DEFAULT)
-        GST_WARNING ("plugin \"%s\" failed to initialise", plugin->filename);
+        GST_WARNING ("plugin \"%s\" failed to initialise",
+            GST_STR_NULL (plugin->filename));
       return NULL;
     }
   } else {
     if (!((desc->plugin_init) (plugin))) {
       if (GST_CAT_DEFAULT)
-        GST_WARNING ("plugin \"%s\" failed to initialise", plugin->filename);
+        GST_WARNING ("plugin \"%s\" failed to initialise",
+            GST_STR_NULL (plugin->filename));
       return NULL;
     }
   }
@@ -653,8 +655,9 @@ check_release_datetime (const gchar * date_time)
 static GMutex gst_plugin_loading_mutex;
 
 #define CHECK_PLUGIN_DESC_FIELD(desc,field,fn)                               \
-  if (G_UNLIKELY ((desc)->field == NULL)) {                                  \
-    GST_ERROR ("GstPluginDesc for '%s' has no %s", fn, G_STRINGIFY (field)); \
+  if (G_UNLIKELY ((desc)->field == NULL || *(desc)->field == '\0')) {        \
+    g_warning ("Plugin description for '%s' has no valid %s field", fn, G_STRINGIFY (field)); \
+    goto return_error;                                                       \
   }
 
 /**
@@ -776,8 +779,7 @@ gst_plugin_load_file (const gchar * filename, GError ** error)
   plugin->orig_desc = desc;
 
   if (new_plugin) {
-    /* check plugin description: complain about bad values but accept them, to
-     * maintain backwards compatibility (FIXME: 0.11) */
+    /* check plugin description: complain about bad values and fail */
     CHECK_PLUGIN_DESC_FIELD (plugin->orig_desc, name, filename);
     CHECK_PLUGIN_DESC_FIELD (plugin->orig_desc, description, filename);
     CHECK_PLUGIN_DESC_FIELD (plugin->orig_desc, version, filename);
