@@ -510,7 +510,7 @@ gst_parse_test_element_class_init (GstParseTestElementClass * klass)
   gst_element_class_add_pad_template (gstelement_class,
       gst_static_pad_template_get (&test_element_pad_template));
 
-  gst_element_class_set_details_simple (gstelement_class,
+  gst_element_class_set_metadata (gstelement_class,
       "Test element for parse launch tests", "Source",
       "Test element for parse launch tests in core",
       "GStreamer Devel <gstreamer-devel@lists.sf.net>");
